Worker_jobs
===================
.. autoclass:: dvg_qdeviceio.Worker_jobs
   :members: ,
   :member-order: bysource
   :show-inheritance:

Methods
--------------------

.. automethod:: dvg_qdeviceio.Worker_jobs.send
.. automethod:: dvg_qdeviceio.Worker_jobs.add_to_queue
.. automethod:: dvg_qdeviceio.Worker_jobs.process_queue